Füllhorn Icon Set – Solarpunk Outline

# 🌿 Füllhorn Icon Set

Solarpunk Outline Style – 82 Icons

82 Icons
24×24 viewBox · stroke-width: 1.5 · currentColor

## Größen-Vorschau

16px
24px
32px
48px

## Farbvarianten

Fern auf Hell
Weiß auf Dunkel

## Kategorien – Gemüse & Obst (4)

Gemüse
vegetable
Kräuter
herbs
Obst
fruit
Beeren
berries

## Kategorien – Fleisch & Fisch (8)

Fleisch
meat
Rindfleisch
beef
Schwein
pork
Geflügel
poultry
Hackfleisch
ground-meat
Fisch
fish
Fettfisch
fish-fatty
Wurst
sausage

## Kategorien – Backwaren (3)

Backwaren
bakery
Brot
bread
Kuchen
cake

## Kategorien – Milchprodukte (4)

Milch
milk
Butter
butter
Käse
cheese
Joghurt
yogurt

## Kategorien – Fertiggerichte (2)

Fertiggericht
ready-meal
Suppe
soup

## Kategorien – Eingemachtes süß (5)

Marmelade
jam
Gelee
jelly
Kompott
compote
Obstmus
puree
Sirup
syrup

## Kategorien – Eingemachtes herzhaft (8)

Eingelegtes
pickles
Chutney
chutney
Relish
relish
Tomatensoße
tomato-sauce
Ketchup
ketchup
Pesto
pesto
Senf
mustard
Sauerkraut
sauerkraut

## Lagerorte (5)

Kühlschrank
fridge
Gefriertruhe
freezer-chest
Gefrierfach
freezer
Keller
cellar
Vorratsschrank
pantry

## Navigation (5)

Übersicht
home
Erfassen
add
Vorrat
inventory
Weiter
forward
Pfeil rechts
chevron-right

## Actions (14)

Entnehmen
take-out
Bearbeiten
edit
Löschen
delete
Speichern
save
Zurück
back
Schließen
close
Suchen
search
Filter
filter
Sortieren
sort
Pfeil hoch
arrow-up
Pfeil runter
arrow-down
Reihenfolge
reorder
Speichern+Weiter
save-next
Minus/Entfernen
minus

## Item Types (5)

Frisch
fresh
TK-Ware
frozen-bought
Eingefr.
frozen-home
Selbst eingefr.
frozen-self
Eingemacht
preserved

## Status (9)

Haltbarkeit
calendar
Warnung
warning
OK
ok
Kritisch
critical
Abgelaufen
expired
Info
info
Keine Ergebnisse
search-off
Historie
history
Passwort
lock

## Sonstige (10)

Einstellungen
settings
Benutzer
user
Logout
logout
Menge
scale
Notizen
notes
Kategorie
category
Ort/Standort
place
Benutzer (Mehrzahl)
people
Benutzer deaktiv.
person-off
Küche
kitchen

Format: SVG, 24×24 viewBox
Stroke: currentColor, 1.5px, round caps/joins
Kompatibel: CSS color inheritance, alle Größen